# Programmers : MrGps + pyhanzo
### To Use Library Download it : pip install TrackCobra
#### Through the library, you can do many things, such as logging in to Facebook or Instagram... You can pull all the information through a very simple code
####
#### ---------------------------
### Code Can You Now Your IP
#### from TrackCobra import Who_Iam
#### ip = Who_Iam.Information("IP")
#### print(ip)
#### ---------------------------
### Code Login Account Instgram
#### from TrackCobra import Login
#### log = Login.Instagram("Your Email","Your Password")
#### print(log)
#### If you want to log in to Facebook or Twitter, you can register just change the Instagram name in the code and put Tiwtter or Facebook
## And the opposite is true for all codes
### If you want to know how to use it, visit our github site and you will find many instructions for the codes Url: github.com/MrGps1/MrGps
